Skip to contents

reads values from the enviroment for configurating a google drive client for accesing gdrive file or gsheets data

Usage

gdrive_client_setup()

Value

'client' for use in drive_auth_configure or