Skip to contents

read the list of urls, read, confirm column format, validate and when using in development mode, make sure do run devtools::load_all() to get all the collaboratR functions loaded save to CSV

Usage

validate_all(urls.df = NULL, drive_email = NULL)