Skip to contents

convenience to create validation results from a yaml file

Usage

validate_from_file(data_df, file)

Arguments

file

yaml formatted file with rules for the validate package

data_dfe

data frame of data

Value

the outupt from confront function