get a google drive 'client' for authentication from env file
Source:R/gdrive.R
gdrive_client_setup.Rdreads values from the enviroment for configurating a google drive client for accesing gdrive file or gsheets data
R/gdrive.R
gdrive_client_setup.Rdreads values from the enviroment for configurating a google drive client for accesing gdrive file or gsheets data