csvs/sheets created to specs may not be in order of specification, but we want to get the col types in order that the sheet is actually in This get the colum types in the order the columns appear in the spreadsheet that is read (in case columns are re-ordered) by checking one by one requires the a spec data frame that must have columns named col_name and col_type