given a google filepath , find it in our shared drive and read it in. If there are multiple files found with the same name on the share drive, throws a warning and reads only the first one it finds (which may not be the most recent one! )
Arguments
optional name of the shared drive to look in, will read from the environment 'PROJECT_SHARE_DRIVE' ignored if URL is sent
- drive_path
optional standard path for project files, will read from environment 'PROJECT_SHARE_DRIVE_PATH'; ignored if URL is sent
- filepath
full name of the file (e.g. myfile.csv ), which could include sub-folder (myfiles/myfile.csv) OR google drive URL