this reads from the environment (or Renviron file) to get configuration details for authenticating to a google sheets service note that this is nearly identical to gdrive_setup but only for google sheets google sheets has a different API and different permissions in the cloud console to read