Note This is only for google sheets, not CSVs or other data files. this can read either type of data sheet (e.g. either tab) and returns th To remove the 2nd "description" row, it downloads as CSV, removes the line, and reads back in This is a generic function, and does not use a specification file, see read_data_sheet() below for that.
Arguments
- gurl
url of a google sheet (and only a google sheet, not doc)
- sheet_id
optional the name or number of the tab (1, 2), defaults to 1, see read_sheet() fn
- has_description_line
does the sheet have row 2 as description of data, if TRUE (default), remove it
- drive_email
optional drive email, required if you have not already logged in or don't have it set in Env. See gdrive_setup()