R/database.R
read_url_list.Rd
google sheet requires two column on for id one for the url for that id the names of which can be anything but
read_url_list(gurl, id_column = "id", url_column = "url", drive_email = NULL)
dataframe with columns from google sheet with at least two columns 'id' and 'url' plus other columns in original sheet