remove line 2 from a csv file, used by data-entry for column directions/description.
Source:R/gdrive.R
remove_comment_line.Rdthis will read all lines of a test file (which can take a long time/memory for a long file), remove some of the lines by number and write those to disk. If no new_file_path param is sent, will overwrite the original file which will be lost it will write a file with standard POSIX (linux/mac) line endings for now