given a character code, return the conversion function to use on a value. This is useful for spreadsheets/csvs that don't adapt well to conversion (even with formats specific) and hence manual converting from character is needed Yes this is probably a re-make of what's in read.csv or read_csv but those weren't amenable to a specific use case