read the list of urls, read, confirm column format, validate and when using in development mode, make sure do run devtools::load_all() to get all the collaboratR functions loaded save to CSV
Source: R/validator.R
validate_all.Rdread the list of urls, read, confirm column format, validate and
when using in development mode, make sure do run devtools::load_all()
to get all the collaboratR functions loaded
save to CSV